Changelog for pyramid_notebook
==============================

0.1.3 (2015-12-19)
------------------

- Fixing MANIFEST.in and release issues due to setuptools_git not present


0.1.2 (2015-12-19)
------------------

- Fixed README markup

- Fixed broken drone.io integration which prevented tests to pass on CI

0.1.1 (2015-12-19)
------------------

- Fixed broken setup.py classifiers

0.1 (2015-12-19)
----------------

- Initial release.
